package
Version:
v0.5.1
Opens a new window with list of versions in this module.
Published: Dec 8, 2025
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
ParseItalianDate parses a date string in the format "mese anno ore hh:mm" (e.g., "febbraio 2025 ore 09:30")
and returns a time.Time object.
func GetExamsForSubject(courseType, courseId, subjectName string) ([]Exam, error)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.